EventType

Enum EventType 

pub enum EventType {
    Dialogue,
    Comment,
    Picture,
    Sound,
    Movie,
    Command,
}
Event type discriminant for different kinds of timeline events

Determines how the event is processed during subtitle rendering. Different types have different behaviors during playback.

Variants



Dialogue

Dialogue line (displayed during playback)



Comment

Comment (ignored during playback)



Picture

Picture display event



Sound

Sound playback event



Movie

Movie playback event



Command

Command execution event

Implementations

Source

impl EventType

pub fn parse_type(s: &str) -> Option<EventType>

Parse event type from string

Converts ASS event type names to the corresponding enum variant. Returns None for unrecognized event types.

Examples
assert_eq!(EventType::parse_type("Dialogue"), Some(EventType::Dialogue));
assert_eq!(EventType::parse_type("Comment"), Some(EventType::Comment));
assert_eq!(EventType::parse_type("Unknown"), None);
pub const fn as_str(self) -> &'static str

Get string representation for serialization

Returns the canonical ASS event type name for this variant.