pub struct RenderContext { /* private fields */ }Expand description
Rendering context containing fonts, resolution, and configuration
Implementations
Sourceimpl RenderContext
impl RenderContext
Sourcepub fn new(width: u32, height: u32) -> Self
pub fn new(width: u32, height: u32) -> Self
Create a new render context with the given dimensions
Sourcepub fn with_font_database(
width: u32,
height: u32,
font_database: FontDatabase,
) -> Self
pub fn with_font_database( width: u32, height: u32, font_database: FontDatabase, ) -> Self
Create context with custom font database
Sourcepub fn set_playback_resolution(&mut self, x: u32, y: u32)
pub fn set_playback_resolution(&mut self, x: u32, y: u32)
Set playback resolution (from script info)
Sourcepub fn set_storage_resolution(&mut self, x: u32, y: u32)
pub fn set_storage_resolution(&mut self, x: u32, y: u32)
Set storage resolution (original script resolution)
Sourcepub fn set_frame_rate(&mut self, fps: f32)
pub fn set_frame_rate(&mut self, fps: f32)
Set frame rate
Sourcepub fn set_pixel_aspect_ratio(&mut self, par: f32)
pub fn set_pixel_aspect_ratio(&mut self, par: f32)
Set pixel aspect ratio
Sourcepub fn font_database(&self) -> &FontDatabase
pub fn font_database(&self) -> &FontDatabase
Get font database
Sourcepub fn font_database_mut(&mut self) -> &mut FontDatabase
pub fn font_database_mut(&mut self) -> &mut FontDatabase
Get mutable font database
Sourcepub fn playback_res_x(&self) -> u32
pub fn playback_res_x(&self) -> u32
Get playback resolution X
Sourcepub fn playback_res_y(&self) -> u32
pub fn playback_res_y(&self) -> u32
Get playback resolution Y
Sourcepub fn storage_res_x(&self) -> u32
pub fn storage_res_x(&self) -> u32
Get storage resolution X
Sourcepub fn storage_res_y(&self) -> u32
pub fn storage_res_y(&self) -> u32
Get storage resolution Y
Sourcepub fn frame_rate(&self) -> f32
pub fn frame_rate(&self) -> f32
Get frame rate
Sourcepub fn pixel_aspect_ratio(&self) -> f32
pub fn pixel_aspect_ratio(&self) -> f32
Get pixel aspect ratio
Sourcepub fn render_scale_x(&self) -> f32
pub fn render_scale_x(&self) -> f32
Calculate X scale factor from playback to render resolution
Sourcepub fn render_scale_y(&self) -> f32
pub fn render_scale_y(&self) -> f32
Calculate Y scale factor from playback to render resolution