Debug and analysis tools for subtitle rendering Debug and analysis tools for ASS subtitle rendering
This module provides comprehensive debugging capabilities including:
- Frame analysis and benchmarking
- Visual comparison tools
- Performance profiling
Re-exports
pub use analyzer::AnalysisReport;pub use analyzer::FrameAnalyzer;pub use benchmarking::quick_benchmark;pub use benchmarking::BenchmarkConfig;pub use benchmarking::BenchmarkResult;pub use benchmarking::PerformanceBenchmark;pub use benchmarking::PerformanceMetrics;pub use info::BoundingBoxInfo;pub use info::DirtyRegionInfo;pub use info::FrameComparison;pub use info::FrameDebugInfo;pub use inspector::FrameInspector;pub use player::DebugPlayer;pub use player::PlayerFrame;
Modules
- analyzer
- Frame analysis and reporting tools Frame analysis tools for detailed debugging and profiling
- benchmarking
- Performance benchmarking tools Benchmarking and performance analysis for the renderer
- color_
diagnostic - Color diagnostic utilities Color diagnostic tool for debugging rendering issues
- info
- Debug information data structures Debug information data structures for rendered frames.
- inspector
- Frame inspection tools
- player
- Debug player for subtitle playback
- util
- Frame helper utilities for the debug renderer Frame helper utilities for the debug renderer.
- visual_
comparison - Visual comparison utilities Visual comparison and debugging tools for ASS rendering
Structs
- Debug
Renderer - Debug renderer that wraps a normal renderer and provides additional debugging info